@@ -8,10 +8,10 @@ import os
 import re
 import tarfile
 
-import requests
-
 from pugnlp.futil import path_status, find_files
 
+from nlpia.web import requests_get
+
 
 # In[ ]:
 
@@ -66,7 +66,7 @@ def download_file(url, data_path='.', filename=None, size=None, chunk_size=4096,
         print('requesting URL: {}'.format(url))
     else:
         tqdm_prog = no_tqdm
-    r = requests.get(url, stream=True, allow_redirects=True, timeout=5)
+    r = requests_get(url, stream=True, allow_redirects=True, timeout=5)
     size = r.headers.get('Content-Length', None) if size is None else size
     print('remote size: {}'.format(size))
 
@@ -334,7 +334,7 @@ def test_len(data, maxlen):
         elif len(sample) < maxlen:
             padded += 1
         else:
-            exact += 1 
+            exact += 1
     print('Padded: {}'.format(padded))
     print('Equal: {}'.format(exact))
     print('Truncated: {}'.format(truncated))
@@ -493,7 +493,7 @@ import numpy as np
 
 
 def onehot_encode(dataset, char_indices, maxlen):
-    """ 
+    """
     One hot encode the tokens
 
     Args:
